@@ -1,2 +1,2 @@
-def pozdrav(name)
+def pozdrav(name):
  print("Zdravo," + name)
